Documentation
¶
Index ¶
- Variables
- func AddLabel(projectID *uint64, name string)
- func AddSection(projectId uint64, section Section) (sectionId uint64, _ error)
- func FromHex6(color string) (clr.C16, error)
- type ID
- type Label
- type Labels
- type Priority
- type Project
- type Projects
- type Section
- type Sections
- type Server
- type Task
- type Tasks
Constants ¶
This section is empty.
Variables ¶
var ( ErrInsert = errors.New("insert failed") ErrLabelID = errors.New("invalid label ID") ErrNotFound = errors.New("no document found") ErrProjectID = errors.New("invalid project ID") ErrSectionID = errors.New("invalid section ID") ErrTableMissing = errors.New("database table missing") ErrTaskID = errors.New("invalid task ID") )
Functions ¶
Types ¶
type Project ¶
type Project struct {
ID uint64
Name string
Description string
Created time.Time
Parent uint64
Color clr.C16
Icon []byte
Hidden bool
Trashed bool
Labels Labels // Unique labels in each project.
SortOrder uint64 // Order that projects are displayed in.
Tasks Tasks
Sections Sections
UnfinishedQty uint16
}
func ProjectById ¶
func ProjectGet ¶
func (*Project) UnmarshalJ ¶
type Server ¶
type Server struct {
// contains filtered or unexported fields
}
Server configuration options.
type Task ¶
type Task struct {
ID uint64
Name string
Description string
Due dateTime
Updated dateTime
Created dateTime
Project *Project
Section *Section
Parent uint64 // Project ID - for subtasks in different projects?
Priority
Labels Labels
Reminders []time.Time
// Location // Reminder when you reach a location.
SubTasks Tasks
Completed time.Time // When the task was completed. Handy for correcting when tasks were completed in the past.
Done bool // If the task is complete or not
Ignore bool // If the task was not completed in time or no longer needed. (hidden from the task list but isn't removed from calendar)
}
func (*Task) SetPriority ¶
SetPriority validates the priority value is correct.
type Tasks ¶
type Tasks []Task
func GetTasksCompleted ¶
func GetTasksCompleted() Tasks
func GetTasksUncompleted ¶
func GetTasksUncompleted() Tasks
func GetUpcoming ¶
func GetUpcoming() Tasks
Source Files
¶
Click to show internal directories.
Click to hide internal directories.